<?php

if ( class_exists( 'Snow3d_settings_config' ) ) {
	return;
}

class Snow3d_settings_config {

	public $args = array();
	public $sections = array();
	public $ReduxFramework;

	public function __construct( $main ) {
		if ( ! class_exists( 'ReduxFramework' ) ) {
			return;
		}

		$this->main = $main;
		$this->initSettings();
	}

	public function initSettings() {
		am_style( 'assets/markdown/markdown', __FILE__, 'redux', false, $this->main->VERSION );
		am_style( 'style', __FILE__, 'snow3d-admin-style', false, $this->main->VERSION );

		$this->setArguments();
		$this->setSettings();
		$this->setSections();

		if ( ! isset( $this->args['opt_name'] ) ) {
			return;
		}

		add_filter( 'plugin_action_links_' . sprintf('%s/%s.php', $this->main->SLUG, $this->main->SLUG) , array($this, 'createPluginLinks') );

		add_action( 'redux/loaded', array( $this, 'remove_demo' ) );
		$this->ReduxFramework = new ReduxFramework( $this->sections, $this->args );
	}

	public function createPluginLinks( $links ) {
		$links[0] = '<a href="'. get_admin_url(null, $this->args['page_parent'] . '?page='.$this->main->SLUG) .'">Settings</a>';
		$links[] = '<a href="http://amino-studio.com/" target="_blank">More plugins by Amino-Studio</a>';
		return $links;
	}

	public function setArguments() {
		$this->args = array(
			'opt_name'           => $this->main->SLUG,
			'display_name'       => $this->main->name,
			'display_version'    => $this->main->VERSION,
			'menu_type'          => 'submenu',
			'allow_sub_menu'     => false,
			'menu_title'         => __( 'Snow 3D', $this->main->SLUG ),
			'page_title'         => __( $this->main->name . ' Settings', $this->main->SLUG ),
			'dev_mode'           => $this->main->IS_DEBUG,
			'customizer'         => false,
			'page_parent'        => 'options-general.php',
			'page_permissions'   => 'manage_options',
			'menu_icon'          => '',
			'last_tab'           => '',
			'page_icon'          => 'icon-themes',
			'page_slug'          => $this->main->SLUG,
			'save_defaults'      => true,
			'update_notice'      => false,
			'show_import_export' => true,
			'footer_credit'      => 'Created by Amino-Studio. Powered by Redux.'
		);
	}

	public function setSettings() {
		$sample_patterns_path =  dirname(dirname(__FILE__)) . '/library/snow-3d/flakes';
		$sample_patterns_url  = plugins_url('library/snow-3d/flakes/', dirname(__FILE__));


		$images = array(
			'id'       => 'default-images',
			'type'     => 'checkbox',
			'title'    => __( 'Default images', $this->main->SLUG ),
			'subtitle' => __( '', $this->main->SLUG ),
			'options'  => array(),
			'default'  => array()
		);

		if ( is_dir( $sample_patterns_path ) ) :
			$i = 0;
			if ( $sample_patterns_dir = opendir( $sample_patterns_path ) ) :
				while ( ( $sample_patterns_file = readdir( $sample_patterns_dir ) ) !== false ) {
					if ( stristr( $sample_patterns_file, '.png' ) !== false || stristr( $sample_patterns_file, '.jpg' ) !== false ) {
						$name              = explode( '.', $sample_patterns_file );
						$name              = str_replace( '.' . end( $name ), '', $sample_patterns_file );

						$images['options'][$name] = am_dom(
							array(
								'tag'=>'img',
								'src'=>$sample_patterns_url . $sample_patterns_file
							)
						);
						$images['default'][$name] = (++$i > 1 && $i < 15) ? '1' : '0';
					}
				}
			endif;
		endif;

		if(!function_exists('overload_custom_gallery_field_path_snow3d')) {
			function overload_custom_gallery_field_path_snow3d( $field ) {
				return dirname( dirname( __FILE__ ) ) . "/vendor/custom_gallery/field_custom_gallery.php";
			}
		}

		add_filter( "redux/snow-3d/field/class/custom_gallery", "overload_custom_gallery_field_path_snow3d" );


		$this->sections[] = array(
			'title'  => __( 'General Settings', $this->main->SLUG ),
			'icon'   => 'el-icon-cogs',
			'fields' => array(
				array(
					'id'       => 'enabled',
					'type'     => 'switch',
					'title'    => __( 'Snow 3D', $this->main->SLUG ),
					'subtitle' => __( 'You can totally disable plugin here.', $this->main->SLUG ),
					"default"  => '0',
					'on'       => __( 'Enabled', $this->main->SLUG ),
					'off'      => __( 'Disabled', $this->main->SLUG ),
				),


				array(
					'id'       => 'allPages',
					'type'     => 'switch',
					'title'    => __( 'Show on Pages',  $this->main->SLUG ),
					"default"  => '1',
					'on'       => __( 'All', $this->main->SLUG ),
					'off'      => __( 'Special', $this->main->SLUG ),
				),
				array(
					'id'       => 'specialPages',
					'required' => array( 'allPages', '=', '0' ),
					'type'     => 'select',
					'data'     => 'pages',
					'multi'    => true,
					'title'    => __( 'Pages', $this->main->SLUG )
				),

				array(
					'id'            => 'num',
					'type'          => 'slider',
					'title'         => __( 'Number of elements', $this->main->SLUG ),
					'subtitle'      => __( 'Total quantity of elements on the page.', $this->main->SLUG ),
					'default'       => 300,
					'min'           => 0,
					'step'          => 5,
					'max'           => 1500,
					'display_value' => 'text'
				),

				array(
					'id'            => 'speed',
					'type'          => 'slider',
					'title'         => __( 'Speed', 'redux-framework-demo', $this->main->SLUG ),
					'subtitle'      => __( 'Defines speed of animation.', $this->main->SLUG ),
					'desc'          => __( '0.2 - very slow, 3 - very fast', $this->main->SLUG ),
					'default'       => 1,
					'min'           => 0,
					'step'          => .1,
					'max'           => 4,
					'resolution'    => 0.1,
					'display_value' => 'text'
				),
				array(
					'id'       => 'direction',
					'type'     => 'radio',
					'title'    => __( 'Direction',  $this->main->SLUG ),
					'subtitle' => __( 'Defines direction of animation.', $this->main->SLUG ),
					'options'  => array(
						'down' => 'Down',
						'up' => 'Up'
					),
					'default'  => 'down'
				),
				array(
					'id'       => 'fadeScroll',
					'type'     => 'switch',
					'title'    => __( 'Fade on Scroll',  $this->main->SLUG ),
					'subtitle' => __( 'Hides animation when you scroll the page down.', $this->main->SLUG ),
					"default"  => '1',
					'on'       => __( 'Yes', $this->main->SLUG ),
					'off'      => __( 'No', $this->main->SLUG ),
				),

				array(
					'id'       => 'closeButton',
					'type'     => 'switch',
					'title'    => __( 'Close Button Enabled',  $this->main->SLUG ),
					"default"  => '1',
					'on'       => __( 'Yes', $this->main->SLUG ),
					'off'      => __( 'No', $this->main->SLUG ),
				),
				array(
					'id'       => 'closeButtonText',
					'required' => array( 'closeButton', '=', '1' ),
					'type'     => 'text',
					'title'    => __( 'Close Button Text', $this->main->SLUG ),
					'default'  => 'Hide Snow 3D'
				),


				array(
					'id'       => 'closeButtonMode',
					'required' => array( 'closeButton', '=', '1' ),
					'type'     => 'button_set',
					'title'    => __( 'Close Button Click Mode',  $this->main->SLUG ),
					'subtitle' => __( 'Can hide animation once, for session or any number of days.', $this->main->SLUG ),
					"default"  => 'session',
					'options'  => array(
						'session' => 'Session',
						'once' => 'Once',
						'days' => 'Days'
					),
				),
				array(
					'id'       => 'closeButtonStyles',
					'required' => array( 'closeButton', '=', '1' ),
					'type'     => 'text',
					'title'    => __( 'Close Button Custom Styles', $this->main->SLUG ),
					'desc'    => __( 'Styles like: "border-radius: 25px; margin: 15px; opacity: 0.6;". You can read more about CSS styles <a href="http://www.w3schools.com/html/html_css.asp" target="_blank">Here</a>.', $this->main->SLUG ),
					'default'  => ''
				),

				array(
					'id'            => 'closeButtonModeDays',
					'type'          => 'slider',
					'required' => array( 'closeButtonMode', '=', 'days' ),

					'title'         => __( 'Close Button Days', $this->main->SLUG ),
					'default'       => 3,
					'min'           => 0,
					'step'          => 1,
					'max'           => 150,
					'display_value' => 'text'
				),

				array(
					'id'       => 'showOnce',
					'type'     => 'button_set',
					'title'    => __( 'Show Once',  $this->main->SLUG ),
					'subtitle' => __( 'Can show animation once per session, per any number of days.', $this->main->SLUG ),
					"default"  => '',
					'options'  => array(
						'' => 'Off',
						'session' => 'Session',
						'days' => 'Days'
					),
				),
				array(
					'id'            => 'showOnceDays',
					'type'          => 'slider',
					'required' => array( 'showOnce', '=', 'days' ),

					'title'         => __( 'Show Once Per Days', $this->main->SLUG ),
					'default'       => 3,
					'min'           => 0,
					'step'          => 1,
					'max'           => 150,
					'display_value' => 'text'
				),

				array(
					'id'       => 'disableMouse',
					'type'     => 'switch',
					'title'    => __( 'Disable Mouse',  $this->main->SLUG ),
					'subtitle' => __( 'Define if you want to disable live camera.', $this->main->SLUG ),
					"default"  => '0',
					'on'       => __( 'Yes', $this->main->SLUG ),
					'off'      => __( 'No', $this->main->SLUG ),
				),
				array(
					'id'       => 'enableMobile',
					'type'     => 'switch',
					'title'    => __( 'Enable on Mobiles',  $this->main->SLUG ),
					'subtitle' => __( 'Define if you want to enable on mobile devices.', $this->main->SLUG ),
					"default"  => '0',
					'on'       => __( 'Yes', $this->main->SLUG ),
					'off'      => __( 'No', $this->main->SLUG ),
				),
				array(
					'id'            => 'scale',
					'type'          => 'slider',
					'title'         => __( 'Level of image scale', $this->main->SLUG ),
//					'subtitle' => __( 'Defines size random range.', $this->main->SLUG ),
					'default'       => array(
						1 => 10,
						2 => 30,
					),
					'min'           => 1,
					'step'          => 1,
					'max'           => 60,
					'display_value' => 'text',
					'handles'       => 2,
				),
			)
		);


		$this->sections[] = array(
			'title'  => __( 'Snowflakes', $this->main->SLUG ),
			'icon'   => 'el-icon-picture',
			'subsection' => true,
			'fields' => array(
				array(
					'id'   => '',
					'type' => 'info',
					'desc' => __( 'Choose images which you want to appear on the animation. You can use available out-of-box images.', $this->main->SLUG )
				),

				$images
			)
		);


		$this->sections[] = array(
			'type' => 'divide',
		);

	}

	public function setSections() {
		am_require( 'amino/classes/common/parsedown.php', $this->main->plugin__FILE__ );


		$this->sections[] = array(
			'title'  => __( 'Documentation', $this->main->SLUG ),
			'icon'   => 'el-icon-question-sign',
			'fields' => array(
				array(
					'id'      => am_id(),
					'type'    => 'raw',
					'content' => Am_Common_Parsedown::instance()->setBreaksEnabled( true )->parse(
						file_get_contents( dirname( __FILE__ ) . '/docs/documentation.md' ),
						plugins_url( 'docs/', __FILE__ )
					)
				),
			)
		);


		$this->sections[] = array(
			'id'     => 'activation',
			'icon'   => 'el-icon-retweet',
			'title'  => __( 'Activation', $this->main->SLUG ),
			'fields' => array(

				array(
					'id'       => 'auto_updates_enable',
					'type'     => 'switch',
					'title'    => __( 'Enable Auto Updates', 'wpex' ),
					'subtitle' => __( 'You can toggle the automatic updates on or off.', $this->main->SLUG ),
					"default"  => '0',
					'on'       => __( 'On', $this->main->SLUG ),
					'off'      => __( 'Off', $this->main->SLUG ),
				),
				array(
					'id'                => 'auto_updates_key',
					'type'              => 'text',
					'title'             => __( 'Item Purchase Code', $this->main->SLUG ),
					'subtitle'          => __( 'Enter your Envato license key here if you wish to receive auto updates.', $this->main->SLUG ) . '<br /<br /><br />' . am_dom( array(
								'tag' => 'img',
								'src' => plugins_url( 'assets/license-key-hint.jpg', __FILE__ )
							) ),
					'required'          => array( 'auto_updates_enable', 'equals', '1' ),
				//	'validate_callback' => array($this, 'validatePurchaseCode')
//			        )
				),
			),
		);
	}

	function validatePurchaseCode( $field, $value, $existing_value ) {
		$error = false;

		if ( !$value || !preg_match("/^\w{8}-\w{4}-\w{4}-\w{4}-\w{11,14}$/i", $value) ) {
			$error        = true;
			$field['msg'] = 'Sorry, you enter invalid Purchase Code';
		}


		$return['value'] = $value;
		if ( $error == true ) {
			$return['error'] = $field;
		}

		return $return;
	}

	function remove_demo() {
		if ( class_exists( 'ReduxFrameworkPlugin' ) ) {
			remove_filter( 'plugin_row_meta', array( ReduxFrameworkPlugin::instance(), 'plugin_metalinks' ), null, 2 );
			remove_action( 'admin_notices', array( ReduxFrameworkPlugin::instance(), 'admin_notices' ) );
		}
	}
}